[Freeswitch-svn] [commit] r3336 - in freeswitch/trunk/src: . include

Freeswitch SVN mikej at freeswitch.org
Sun Nov 12 16:16:47 EST 2006


Author: mikej
Date: Sun Nov 12 16:16:46 2006
New Revision: 3336

Modified:
   freeswitch/trunk/src/include/switch_ivr.h
   freeswitch/trunk/src/switch_ivr.c

Log:
don't user "new" as a variable name, so we can keep compatible with C++

Modified: freeswitch/trunk/src/include/switch_ivr.h
==============================================================================
--- freeswitch/trunk/src/switch_ivr.c	(original)
+++ freeswitch/trunk/src/switch_ivr.c	Sun Nov 12 16:16:46 2006
@@ -3308,7 +3308,7 @@
 
 }
 
-SWITCH_DECLARE(switch_status_t) switch_ivr_menu_init(switch_ivr_menu_t **new,
+SWITCH_DECLARE(switch_status_t) switch_ivr_menu_init(switch_ivr_menu_t **new_menu,
 													 switch_ivr_menu_t *main,
 													 char *name, 
 													 char *greeting_sound, 
@@ -3385,7 +3385,7 @@
 		menu->flags |= SWITCH_IVR_MENU_FLAG_STACK;
 	}
 	
-	*new = menu;
+	*new_menu = menu;
 	
 	return SWITCH_STATUS_SUCCESS;
 }



More information about the Freeswitch-svn mailing list
--- freeswitch/trunk/src/include/switch_ivr.h	(original)
+++ freeswitch/trunk/src/include/switch_ivr.h	Sun Nov 12 16:16:46 2006
@@ -436,7 +436,7 @@
 
 /*!
  *\brief Create a new menu object.
  *\param new the pointer to the new menu
  *\param main The top level menu, (NULL if this is the top level one).
  *\param name A pointer to the name of this menu.
  *\param greeting_sound Optional pointer to a main sound (press 1 for this 2 for that).
@@ -447,7 +447,7 @@
  *\param pool memory pool (NULL to create one)
  *\return SWUTCH_STATUS_SUCCESS if the menu was created
  */
-SWITCH_DECLARE(switch_status_t) switch_ivr_menu_init(switch_ivr_menu_t **new,
+SWITCH_DECLARE(switch_status_t) switch_ivr_menu_init(switch_ivr_menu_t **new_menu,
 													 switch_ivr_menu_t *main,
 													 char *name, 
 													 char *greeting_sound, 
@@ -436,7 +436,7 @@
 /*!
  *\brief Create a new menu object.
- *\param new the pointer to the new menu
+ *\param new_menu the pointer to the new menu
  *\param main The top level menu, (NULL if this is the top level one).
  *\param name A pointer to the name of this menu.

Modified: freeswitch/trunk/src/switch_ivr.c
==============================================================================